@@ -1,6 +1,6 @@
 package Tangerine::hook::require;
 {
-  $Tangerine::hook::require::VERSION = '0.03';
+  $Tangerine::hook::require::VERSION = '0.05';
 }
 use strict;
 use warnings;
@@ -9,7 +9,7 @@ use Tangerine::Occurence;
 
 sub run {
     my $s = shift;
-    if ($s->[0] eq 'require' && scalar(@$s) == 3) {
+    if (scalar(@$s) >= 2 && $s->[0] eq 'require') {
         my $module = $s->[1];
         return Tangerine::HookData->new(
             modules => { $module => Tangerine::Occurence->new },
